.. image:: https://github.com/jmeyers314/batoid_rubin/workflows/batoid_rubin%20CI/badge.svg
        :target: https://github.com/jmeyers314/batoid_rubin/workflows/batoid_rubin%20CI/badge.svg


batoid_rubin
============

Detailed finite-element models of the Vera C. Rubin Observatory Simonyi Survey Telescope + LSST Camera for use with the `batoid raytracing package <https://github.com/jmeyers314/batoid>`_.


Requirements
============

Known to work with batoid v0.4.


Installation
============

::

    pip install batoid_rubin
